@@ -1,5 +1,5 @@
 /**
- * Copyright 2006-2016 the original author or authors.
+ * Copyright 2006-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,14 +15,16 @@
  */
 package org.objenesis.instantiator.sun;
 
-import org.objenesis.ObjenesisException;
-import org.objenesis.instantiator.ObjectInstantiator;
-import org.objenesis.instantiator.basic.ClassDefinitionUtils;
-
 import java.io.ByteArrayOutputStream;
 import java.io.DataOutputStream;
 import java.io.IOException;
 
+import org.objenesis.ObjenesisException;
+import org.objenesis.instantiator.ObjectInstantiator;
+import org.objenesis.instantiator.annotations.Instantiator;
+import org.objenesis.instantiator.annotations.Typology;
+import org.objenesis.instantiator.basic.ClassDefinitionUtils;
+
 import static org.objenesis.instantiator.basic.ClassDefinitionUtils.*;
 
 /**
@@ -32,6 +34,7 @@ import static org.objenesis.instantiator.basic.ClassDefinitionUtils.*;
  *
  * @author Henri Tremblay
  */
+@Instantiator(Typology.STANDARD)
 public class MagicInstantiator<T> implements ObjectInstantiator<T> {
 
    private static final int INDEX_CLASS_THIS = 1;
@@ -69,6 +72,19 @@ public class MagicInstantiator<T> implements ObjectInstantiator<T> {
       instantiator = newInstantiatorOf(type);
    }
 
+   /**
+    * Get the underlying instantiator.
+    *
+    * {@link MagicInstantiator} is a wrapper around another object
+    * which implements {@link ObjectInstantiator} interface.
+    * This method exposes that instantiator.
+    *
+    * @return the underlying instantiator
+    */
+   public ObjectInstantiator<T> getInstantiator() {
+      return instantiator;
+   }
+
    private <T> ObjectInstantiator<T> newInstantiatorOf(Class<T> type) {
       String suffix = type.getSimpleName();
       String className = getClass().getName() + "$$$" + suffix;
