@@ -1,5 +1,5 @@
 /**
- * Copyright 2006-2016 the original author or authors.
+ * Copyright 2006-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -22,7 +22,8 @@ import org.objenesis.tck.candidates.SerializableNoConstructor;
 import java.io.Serializable;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.InvocationTargetException;
-import java.util.*;
+import java.util.Iterator;
+import java.util.SortedSet;
 
 /**
  * This class will try every available instantiator on the platform to see which works.
@@ -47,14 +48,29 @@ public class SearchWorkingInstantiator implements Serializable { // implements S
     }
 
     public void searchForInstantiator(Class<?> toInstantiate) {
-        SortedSet<Class<?>> classes = ClassEnumerator.getClassesForPackage(ObjectInstantiator.class.getPackage());
+        SortedSet<String> classes = ClassEnumerator.getClassesForPackage(ObjectInstantiator.class.getPackage());
 
-        for (Iterator<Class<?>> it = classes.iterator(); it.hasNext();) {
-            Class<?> c = it.next();
-            if(c.isInterface() || !ObjectInstantiator.class.isAssignableFrom(c)) {
-                continue;
+        for (Iterator<String> it = classes.iterator(); it.hasNext();) {
+            String className = it.next();
+
+            // Skip if inner class of isn't named like a instantiator
+            if(className.contains("$") || !className.endsWith("Instantiator")) {
+               continue;
             }
 
+           Class<?> c = null;
+           try {
+              c = Class.forName(className);
+           }
+           catch(Exception e) {
+              listener.instantiatorUnsupported(c, e);
+              continue;
+           }
+
+           if(c.isInterface() || !ObjectInstantiator.class.isAssignableFrom(c)) {
+                continue;
+           }
+
             Constructor<?> constructor;
             try {
                 constructor = c.getConstructor(Class.class);
